@@ -4,18 +4,20 @@ $PYTHON -m jcc \
 --use_full_names \
 --python orekit \
 --version ${PKG_VERSION} \
---jar $SRC_DIR/orekit-9.3.jar \
---jar $SRC_DIR/hipparchus-core-1.4.jar \
---jar $SRC_DIR/hipparchus-filtering-1.4.jar \
---jar $SRC_DIR/hipparchus-fitting-1.4.jar \
---jar $SRC_DIR/hipparchus-geometry-1.4.jar \
---jar $SRC_DIR/hipparchus-ode-1.4.jar \
---jar $SRC_DIR/hipparchus-optim-1.4.jar \
---jar $SRC_DIR/hipparchus-stat-1.4.jar \
+--jar $SRC_DIR/orekit-10.1.jar \
+--jar $SRC_DIR/hipparchus-core-1.6.jar \
+--jar $SRC_DIR/hipparchus-filtering-1.6.jar \
+--jar $SRC_DIR/hipparchus-fitting-1.6.jar \
+--jar $SRC_DIR/hipparchus-geometry-1.6.jar \
+--jar $SRC_DIR/hipparchus-ode-1.6.jar \
+--jar $SRC_DIR/hipparchus-optim-1.6.jar \
+--jar $SRC_DIR/hipparchus-stat-1.6.jar \
+--jar $SRC_DIR/rugged-2.1.jar \
 --package java.io \
 --package java.util \
 --package java.text \
 --package org.orekit \
+--package org.orekit.rugged \
 java.io.BufferedReader \
 java.io.FileInputStream \
 java.io.FileOutputStream \
@@ -42,13 +44,9 @@ java.util.Locale \
 java.util.Map \
 java.util.Set \
 java.util.TreeSet \
-java.util.concurrent.Executors \
-java.util.concurrent.TimeUnit \
-java.util.concurrent.ExecutorService \
 java.util.stream.Collectors \
 java.util.stream.Stream \
 java.util.stream.DoubleStream \
-java.util.concurrent.atomic.AtomicReference \
 --module $SRC_DIR/pyhelpers.py \
 --reserved INFINITE \
 --reserved ERROR \
@@ -58,7 +56,9 @@ java.util.concurrent.atomic.AtomicReference \
 --reserved min \
 --reserved max \
 --reserved mean \
---files 10 \
+--reserved SNAN \
+--classpath $PREFIX/lib/tools.jar \
+--files 81 \
 --build \
 --install
 
